@@ -1,4 +1,3 @@
-import asyncio
 import urllib.parse
 from typing import List, Optional, Union
 
@@ -10,7 +9,7 @@ from dexguru_sdk.models.choices import *
 from dexguru_sdk.utils.get_query import get_query_from_params
 
 START_BLOCK_TIMESTAMP = 1588723228
-DEFAULT_DOMAIN = 'https://api-public-stage.prod-euc1.dexguru.net'
+DEFAULT_DOMAIN = 'https://api.dev.dex.guru'
 API_VERSION = 'v1/'
 
 
@@ -399,11 +398,3 @@ class DexGuru:
     async def get_amm_inventory(self, chain_id: int, amm: AmmChoices) -> models.AmmModel:
         response: dict = await self._client.get(f'{self._chain_prefix}/{chain_id}/amms/{amm}')
         return models.AmmModel.parse_obj(response)
-
-if __name__ == '__main__':
-
-    sdk = DexGuru(api_key='23gttG8WmsS5EYrzNu3ayfRvqAT_JQMwmI3e8SNuCrg')
-
-    a = asyncio.run(sdk.search_tokens_by_name_or_symbol(1))
-    print(a)
-    pass
