@@ -1,4 +1,6 @@
 import pytest
+from dotenv import load_dotenv
+import os
 
 from dexguru_sdk import models
 from dexguru_sdk.client.exceptions import RequestException
@@ -6,11 +8,12 @@ from dexguru_sdk.models import choices
 from dexguru_sdk.sdk.dg_sdk import DexGuru
 
 DEFAULT_DOMAIN = 'https://api.dev.dex.guru'
+load_dotenv()
 
 
 @pytest.fixture()
 def sdk():
-    yield DexGuru(api_key='CkGWZAcDE0h5XRqR04DhtvCNofL-dfDB4WvLzKhraho',
+    yield DexGuru(api_key=os.environ.get('SDK_API_KEY'),
                   domain=DEFAULT_DOMAIN)
 
 
@@ -129,7 +132,7 @@ async def test_get_txs_mints(sdk):
         limit=1,
         offset=2,
         begin_timestamp=1630934916,
-        end_timestamp=1631021316,
+        end_timestamp=1643867897,
     )
     assert isinstance(txs, models.SwapsBurnsMintsListModel)
     assert len(txs.data) == 1
@@ -139,12 +142,10 @@ async def test_get_txs_mints(sdk):
 
 @pytest.mark.asyncio
 async def test_get_tokens_inventory(sdk):
-    tokens = await sdk.search_tokens_by_name_or_symbol(1, name='eth')
+    tokens = await sdk.search_tokens_by_name_or_symbol(1, search_string='eth')
     assert isinstance(tokens, models.TokensInventoryListModel)
     for token in tokens.data:
         assert isinstance(token, models.TokenInventoryModel)
-    with pytest.raises(Exception, match='Specify name'):
-        await sdk.search_tokens_by_name_or_symbol(1)
 
 
 @pytest.mark.asyncio
@@ -163,14 +164,14 @@ async def test_get_tokens_finance(sdk, btc_address, eth_address):
 
 @pytest.mark.asyncio
 async def test_get_token_inventory(sdk, eth_address):
-    token = await sdk.get_token_inventory(1, eth_address)
+    token = await sdk.get_token_inventory_by_address(1, eth_address)
     assert isinstance(token, models.TokenInventoryModel)
     assert token.address == eth_address
     with pytest.raises(RequestException, match='token_address'):
         # at least 40 symbols
-        await sdk.get_token_inventory(1, 'invalid')
+        await sdk.get_token_inventory_by_address(1, 'invalid')
     with pytest.raises(RequestException, match='Token not found'):
-        await sdk.get_token_inventory(1, eth_address + 'x')
+        await sdk.get_token_inventory_by_address(1, eth_address + 'x')
 
 
 @pytest.mark.asyncio
@@ -180,9 +181,9 @@ async def test_get_token_finance(sdk, eth_address):
     assert token.address == eth_address
     with pytest.raises(RequestException, match='token_address'):
         # at least 40 symbols
-        await sdk.get_token_inventory(1, 'invalid')
-    with pytest.raises(RequestException, match='Token not found'):
-        await sdk.get_token_inventory(1, eth_address + 'x')
+        await sdk.get_token_finance(1, 'invalid')
+    with pytest.raises(RequestException, match='Not found token finance'):
+        await sdk.get_token_finance(1, eth_address + 'x')
 
 
 @pytest.mark.asyncio
@@ -247,7 +248,7 @@ async def test_get_token_market_history(sdk, eth_address):
         assert tx.address == eth_address
         assert isinstance(tx, models.TokenHistoryModel)
 
-    with pytest.raises(RequestException, match='Token not found'):
+    with pytest.raises(RequestException, match='Token history not found'):
         await sdk.get_token_market_history(1, ('i' * 42))
 
 
@@ -300,25 +301,25 @@ async def test_get_wallet_swaps(sdk, eth_wallets):
 
 @pytest.mark.asyncio
 async def test_get_wallet_burns(sdk):
-    txs = await sdk.get_wallet_burns(1, wallet_address='0x935d2fd458fdf41b6f7b62471f593797866a3ce6', limit=6)
+    txs = await sdk.get_wallet_burns(1, wallet_address='0x18c8303797168dbfe5e085222c6de2f23e9e3979', limit=6)
     assert isinstance(txs, models.SwapsBurnsMintsListModel)
     assert txs.total > 0
     assert 0 < len(txs.data) <= 6
     for tx in txs.data:
         assert isinstance(tx, models.SwapBurnMintModel)
-        assert tx.wallet_address == '0x935d2fd458fdf41b6f7b62471f593797866a3ce6'
+        assert tx.wallet_address == '0x18c8303797168dbfe5e085222c6de2f23e9e3979'
         assert tx.transaction_type == choices.TransactionChoices.burn
 
 
 @pytest.mark.asyncio
 async def test_get_wallet_mints(sdk):
-    txs = await sdk.get_wallet_mints(1, wallet_address='0x935d2fd458fdf41b6f7b62471f593797866a3ce6', limit=5)
+    txs = await sdk.get_wallet_mints(1, wallet_address='0xf75e60ffa4c600cbfaf7ab694663fa9ffef0f59a', limit=5)
     assert isinstance(txs, models.SwapsBurnsMintsListModel)
     assert txs.total > 0
     assert 0 < len(txs.data) <= 5
     for tx in txs.data:
         assert isinstance(tx, models.SwapBurnMintModel)
-        assert tx.wallet_address == '0x935d2fd458fdf41b6f7b62471f593797866a3ce6'
+        assert tx.wallet_address == '0xf75e60ffa4c600cbfaf7ab694663fa9ffef0f59a'
         assert tx.transaction_type == choices.TransactionChoices.mint
 
 
